@@ -324,7 +324,7 @@ def forecast_records(recs: pd.DataFrame, rperiods: pd.DataFrame = None, titles:
 
     plot_data = {
         'x_records': dates,
-        'recorded_flows': recs.dropna(axis=0).values,
+        'recorded_flows': recs.dropna(axis=0).values.flatten(),
         'y_max': max(recs.values),
     }
     if rperiods is not None:
@@ -387,7 +387,7 @@ def historic_simulation(hist: pd.DataFrame, rperiods: pd.DataFrame = None, title
 
     plot_data = {
         'x_datetime': dates,
-        'y_flow': hist.values,
+        'y_flow': hist.values.flatten(),
         'y_max': max(hist.values),
     }
     if rperiods is not None:
@@ -490,7 +490,7 @@ def monthly_averages(monavg: pd.DataFrame, titles: dict = False, outformat: str
     scatter_plots = [
         go.Scatter(
             name='Average Monthly Flow',
-            x=pd.to_datetime([f'{i:02}' for i in monavg.index], format='%m').strftime('%B'),
+            x=pd.to_datetime(monavg.index, format='%m').strftime('%B'),
             y=monavg.values.flatten(),
             line=dict(color='blue')
         ),
@@ -532,10 +532,11 @@ def flow_duration_curve(hist: pd.DataFrame, titles: dict = False, outformat: str
         raise ValueError('invalid outformat specified. pick json, plotly, plotly_scatters, or plotly_html')
 
     # process the hist dataframe to create the flow duration curve
-    sorted_hist = hist.values.sort()
+    sorted_hist = hist.values.flatten()
+    sorted_hist.sort()
 
     # ranks data from smallest to largest
-    ranks = len(hist) - scipy.stats.rankdata(sorted_hist, method='average')
+    ranks = len(sorted_hist) - scipy.stats.rankdata(sorted_hist, method='average')
 
     # calculate probability of each rank
     prob = [(ranks[i] / (len(sorted_hist) + 1)) for i in range(len(sorted_hist))]
